@@ -193,7 +193,7 @@ test.cellStyles <- function(wb)
 test.cellBlock2 <- function()
 {
   ext <- "xls"
-  outfile <- paste(OUTDIR, "test_cellBlock.", ext, sep="")
+  outfile <- paste("out/test_cellBlock.", ext, sep="")
   if (file.exists(outfile)) unlink(outfile)
    
   wb <- createWorkbook(type=ext)
@@ -215,8 +215,6 @@ test.cellBlock2 <- function()
   ind  <- which(x < 0, arr.ind=TRUE)
   CB.setFill(cb, fill, ind[,1]+9, ind[,2]+3)  # note the indices offset
 
-  source(paste(SOURCEDIR, "rexcel/trunk/R/CellBlock.R", sep=""))
-  
   # set the border on the top row of the Cell Block
   border <-  Border(color="blue", position=c("TOP", "BOTTOM"),
     pen=c("BORDER_THIN", "BORDER_THICK"))
@@ -456,7 +454,7 @@ test.ranges <- function(wb)
 .main_highlevel_import <- function(ext="xlsx")
 {
   fname <- paste("test_import.", ext, sep="")
-  file <- paste(SOURCEDIR, "rexcel/trunk/inst/tests/", fname, sep="")
+  file <- paste("inst/tests/", fname, sep="")
 
   cat("Testing high level import read.xls\n")
   cat("  read data from mixedTypes\n")
@@ -527,7 +525,7 @@ test.ranges <- function(wb)
 # 
 .main_highlevel_export <- function(ext="xlsx")
 {
-  outfile <- paste(OUTDIR, "test_highlevel_export.", ext, sep="")
+  outfile <- paste("out/test_highlevel_export.", ext, sep="")
   if (file.exists(outfile)) unlink(outfile)  
   
   cat("Testing high level export ... \n")  
@@ -535,19 +533,19 @@ test.ranges <- function(wb)
     date=seq(as.Date("2009-01-01"), by="1 month", length.out=10),
     bool=ifelse(1:10 %% 2, TRUE, FALSE))
 
-  file <- paste(OUTDIR, "test_highlevel_export.", ext, sep="")
+  file <- paste("out/test_highlevel_export.", ext, sep="")
   cat("  write an xlsx file with char, int, double, date, bool columns ...\n")
   write.xlsx(x, file, sheetName="writexlsx")
   
   write.xlsx2(x, file, sheetName="writexlsx2", append=TRUE, row.names=FALSE) 
 
   cat("  test the append argument by adding another sheet ... \n")
-  file <- paste(OUTDIR, "test_highlevel_export.", ext, sep="")
+  file <- paste("out/test_highlevel_export.", ext, sep="")
   write.xlsx(USArrests, file, sheetName="usarrests", append=TRUE)
   cat("Wrote file ", file, "\n\n")
 
   cat("  test writing/reading data.frames with NA values ... \n") 
-  file <- paste(OUTDIR, "test_writeread_NA.", ext, sep="")
+  file <- paste("out/test_writeread_NA.", ext, sep="")
   x <- data.frame(matrix(c(1.0, 2.0, 3.0, NA), 2, 2))
   write.xlsx(x, file, row.names=FALSE)
   xx <- read.xlsx(file, 1)
@@ -564,7 +562,7 @@ test.ranges <- function(wb)
 {
   cat("Testing low level import ...\n")
   fname  <- paste("test_import.", ext, sep="")
-  file   <- paste(SOURCEDIR, "rexcel/trunk/inst/tests/", fname, sep="")
+  file   <- paste("inst/tests/", fname, sep="")
   wb     <- loadWorkbook(file)
   sheets <- getSheets(wb)
 
@@ -603,7 +601,7 @@ test.ranges <- function(wb)
 #
 .main_lowlevel_export <- function(ext="xlsx")
 {
-  outfile <- paste(OUTDIR, "test_export.", ext, sep="")
+  outfile <- paste("out/test_export.", ext, sep="")
   if (file.exists(outfile)) unlink(outfile)
    
   wb <- createWorkbook(type=ext)
@@ -631,7 +629,7 @@ test.ranges <- function(wb)
 {
   cat("Speed test export ... \n")  
 
-  file <- paste(OUTDIR, "test_exportSpeed.", ext, sep="")
+  file <- paste("out/test_exportSpeed.", ext, sep="")
   x <- expand.grid(ind=1:60, letters=letters, months=month.abb)
   x <- cbind(x, val=runif(nrow(x)))
   cat("  writing a data.frame with dim", nrow(x), "x", ncol(x), "\n")
@@ -654,25 +652,13 @@ test.ranges <- function(wb)
   options(width=400)
   require(xlsx)
 
-  if (.Platform$OS.type == "windows") {
-    SOURCEDIR <- "C:/google/"
-    OUTDIR <<- "C:/temp/"
-  } else {
-    SOURCEDIR <- "/home/adrian/Documents/"
-    OUTDIR <<- "/tmp/"
-  }
-  thisFile <- paste(SOURCEDIR, "rexcel/trunk/inst/tests/",
-    "lib_tests_xlsx.R", sep="")
-  #source(paste(SOURCEDIR, "rexcel/trunk/R/utilities.R", sep=""))
-  #source(paste(SOURCEDIR, "rexcel/trunk/R/addDataFrame.R", sep=""))
-  #source(paste(SOURCEDIR, "rexcel/trunk/R/readColumns.R", sep=""))
-  #source(paste(SOURCEDIR, "rexcel/trunk/R/read.xlsx2.R", sep=""))
-  #source(paste(SOURCEDIR, "rexcel/trunk/R/write.xlsx2.R", sep=""))
-  source(thisFile)
+  #source("R/utilities.R")
+  #source("R/addDataFrame.R")
+  source("inst/tests/lib_tests_xlsx.R")
 
 
-  source(paste(SOURCEDIR, "rexcel/trunk/inst/tests/lib_test_issues.R", sep=""))
-  .run_test_issues(SOURCEDIR)
+  source("inst/tests/lib_test_issues.R")
+  .run_test_issues()
 
   
   test.basicFunctions(ext="xlsx")
@@ -692,9 +678,9 @@ test.ranges <- function(wb)
 #  .main_speedtest_export(ext="xls")
  
 
-  allF <- list.files(paste(SOURCEDIR,"rexcel/trunk/R/", sep=""),
-                     full.names=TRUE)
-  lapply(allF, function(fname){cat(fname); source(fname)})
+  ## allF <- list.files(paste(SOURCEDIR,"rexcel/trunk/R/", sep=""),
+  ##                    full.names=TRUE)
+  ## lapply(allF, function(fname){cat(fname); source(fname)})
 
   
 
@@ -707,12 +693,6 @@ test.ranges <- function(wb)
 
 
 
-
-  # source(paste(SOURCEDIR, "rexcel/trunk/R/utilities.R", sep=""))
-
-  ## source(paste(SOURCEDIR, "rexcel/trunk/R/addDataFrame.R", sep=""))
-
-
 ##   cat("Test memory ...\n")
 ##   file <- paste(outdir, "test_exportMemory.xlsx", sep="")
 ##   x <- expand.grid(ind=1:1000, letters=letters, months=month.abb)
